/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvControlIf.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvSignalBiquad.h"
#include "HvMath.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_sbpPCCGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cWo9gxkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nUVabuMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W6tFkCGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EX13jqKT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jUOeg1oo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nnAOChJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dHRSOFEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gQYefG2P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zTUlgBkL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FcnPfWHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NS8Xjm25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nHT79UaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLqy64Xd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PRE3iUQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B1SVvVfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wtttzPA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rhHORIJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UEwCzepf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lfR61gNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4h23LhVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zonIE7VJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_72JZMqxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0TMODZrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HZ27tHd2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WOKr0m7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9vqmrS5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sbYatqaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A4vU5g0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2Mi4uZ3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oda20OHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m45ByE2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DR5Wgnrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_T2Ze8rZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_raYd6ZiO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SyFGz9v3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tZCcTELk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Pc4ILi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NkupUPQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p5qBQNv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PX7lzsbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I6U7iOhu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n4iYPndy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_g4CHLw7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tZukKoFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4fDIOoWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0c31vY3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gAbFo12w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NPjButj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LPei48Pq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QWGFFHdq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zue9kSr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pF5kpmu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4AK04kFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z2jW8X3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ac225Bxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CkeyUgsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xfLAXTBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N4afJPEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qx9tZ9hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oI8yHVBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cP1HnOGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hSCmdpZ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UhojmigP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s4Ql850j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p6Envumk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AZRqLQe2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KBHRS9bU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CtOl6QMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YBp1kKgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SlRW41Dn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FlqJeSrD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oEULgXzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ywxsZrPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2qXmL8SH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2TbpiJuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qAlZcnzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hegu2akz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MmrXYs3Z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_RW0RPSn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E8T7HRpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_InBNuTcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BXCnsDw0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_fogOwRJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3hfgpU3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YruIuSAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nWGFWw8I_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_atDDQZOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vQSOoHap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nMc0neb2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XfH6UFi4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TSCOfOd1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hr2x1d1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xYefeCNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kTuP3iYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0hoPHbq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nH0Mwskq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rVLI4adc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yG317xl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NXFD6YmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gak5Elnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6YorC2XT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P8GRosQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NZ0pDPu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BNes3nef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mhAJLhTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0G9jdtAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sJ9y5uzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_N3DyCE3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w7rCNmv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jsAX24cP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O0y0WUp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aw7av0yF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xq7mXJUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KAk8ODdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CSkvq3TD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L6eOtBot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z1BfVlfm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ti9FS5Kn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TIXOoKw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zkLSjlLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cnrEq9hz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V7QN492f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RiAMLUm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l5DWwum2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GzL67g1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pxa919m6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2pQ2sEH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_U6a3ppET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oBvUm5Di_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ujZTFx79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wc1ooVxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tmYb5h1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oc7l89XA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jk5oO3PG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_egeh4Op6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3UryvCxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HEWLx4Le_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tMlUTZIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rG3SxUmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QFQtKCxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Xskvlfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p2ZS68wu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wfSJarCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVTAW1t3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y9SADpU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V9lBbxMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SflR5C4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7ndI8pkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7LUbn4ml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4b5Mh0cP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EDKqcxQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wQ1YhmcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pj4oPJXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4CedhzbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6hPk3Lwt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qRk6ITuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vWwQlGFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fSng4kbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bb1yOVlI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_odpXx4hb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0B9LNWRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W7PNY2GF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uMqx4KWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jsgdlFAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0RMuyQmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1snr4Bgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kXjXvJFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GGirUaFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qdrB5zU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BSkDaKzf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VUTBUkgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7zZaOCR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zhJYhF8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DMIXYDPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dDfKPTFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w9urElia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4us9VA1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xjqfUQag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jpIz2EWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Xc1rt4Gb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0mTN9Z2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_86xvw9vW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L15I9Kfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_87ucv1C9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H7lHpK35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_710ODwYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fFveFZPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gggjjuFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M4SFKHtH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DzaDAzPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WbNaGn1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g4dcl8cy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EMC3MmJQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BGxe1VUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w1Ro9K08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oyvnvidM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lTCoRNK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Pg78DI8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sEPKP3d0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0HcCXn6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ndfFT7ii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2cCDzd66_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7GlDymp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BxqtJXVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WVIoi2oq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GGOsaSDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8J8uD4gm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_oLXCsvQ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q6wDizef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2AYVy6DK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HJEvf4YB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UYAXRNzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CImUBRBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SAXUhANK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_if5d1fJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pWBiV91c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFQPkvUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hI7C2XcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FwofrmTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hGKE2s0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fsY5CSSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VqtoBMhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9cYcq3JV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tKvsM0Pn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a9bCVOOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DmoxZ5WB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QWEcf4l9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AFMzrp8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DgtPMMbr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OJ7X0xIo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C9xAbKg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_elYxWOC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BSCpoY7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6JwOcHEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KFrZQdAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vgPBIIIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_s0IAc3Jh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JvWG86lF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ybghOLLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6VsdUIsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UEiw3Lz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ASN6Vwnt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c8NOb3xV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_agM27UkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBigE7Ya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FV8BP622_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_unf865fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_POQm0h9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_49oxELmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gvs09Kuq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jF2wZamD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u6YcT4kV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CrvLiuVF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LYsLnDgN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xM4dDsXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9dgFK2Uw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TqVFkzcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SScxZBiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iZjaWRHi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GommmiGl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d6bBW83M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PuS0khCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VzQPVnO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4LSjC46c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4388wl4U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_HQMnGgpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Br4Jg7yu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Sc2JKZlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T7X9QhEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jeN22Ah6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rNlLTCoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VczFl9ps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GtUckfxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yRngRHnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YMUFt45d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eTFo5wdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fvRfRsnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p6pMyQPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZVlWkuvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6AF18NmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TWbAucI7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aqM3zEKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2EyxcWsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gKypZKNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ypxwnv5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t7v0g691_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gSoFGGPW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R5B4o4pl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_29wjeWnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ejUg8sSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EHqiik9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rNY7SybR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o3AK0O9J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wd1NqYVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TP440H09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_az2yH9Qp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mlSUFpXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LgJCmxmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EVe8PKFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GzKqfsVm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4sZZL9to_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uhZDejhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_piatTCP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SdJx2VsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hsnO3u9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mBkd4v0e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3BJSdPB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ddvQpFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uAeNsrD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHYW1hNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vG7FcyqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kE87zTNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lg4AtkSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MV9GTDXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_M3so6w36_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Pc8u0hIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_R580Dnqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hpb35bdX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxO7qwl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2t8s8jxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uoo01CtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lnOLGc9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rUwS4NTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_As364Y5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nXjYN1jr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ORXaktoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ez1mpYHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YdnVsZuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7v7EYEq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2swuJS9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sBy6LxZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wAbnv0NA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_40Jb2wMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9I3lC6jr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mKIWyt4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W3Fov3P3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V7E47729_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oAvwWFyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NWUUBKNA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yYEKLX4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uzeBdUDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LcEVLJuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FYVy4NBw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zzlKqhZg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o1UnoAVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_B7U9ZK3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DnyvdBM8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BUSsijos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AscovyCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hD1ItkDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MMqyJwGq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hE4ipsRe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uulvHMyW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bmB3nopI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_agcvldU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eRNa6KbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ful8laZ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uz8ZHtwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PEbLZdPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMq7J8EO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BUyd8rHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tw8YCMz9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_12ZVrAwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gS008QvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sYZLxT32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qXLsG593_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pKpdxd4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NBQD3GxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JOXLahM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fzawCbDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lZK6F3W7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uqu45Wb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YNtHPbAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0lIpxNXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tm6Kshoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1jn3QTOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XDs28JwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_juxC5iJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JdU9Wt54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SjHLRRn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eqEQ1gjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BtmS0Zrs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_trqte7M8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RFKifFLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_koEBCmiB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zspa6EZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r3xht74j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KoMjQoyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Dk3ZM8wh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UIfJbyvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OsGG86cp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pao8RF2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_amL7Ud1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p0mCy4vR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fy499Tnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0EabteDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UMMDphwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IjH85kEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uoRsfrTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yBmjV1sP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lFZtjTWt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_74AJzyVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PkKs3WUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_St8AfbJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ozqZ2t2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2iF4ELAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fp50sulh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KyHQdTWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plAMAJYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lfvXlcSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M6F6BXJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VTtdCvJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FutksYDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IDRGfm1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Vq58HLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cT9wiS3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtcHjImf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uCRHI0lx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rdNXTh9M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z9R4mXyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pCIy5uO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GfCCC0cb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Dcrrlnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gjkvc0oJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YEWTyzN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3vrdHDjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W8mGZLm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MluBFVOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WtPCcl5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qoaOABPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gLULnQjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bOqp5u4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PCgrtIHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PfmJnP1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KZsxynh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_glX11rbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s3Yvbn4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5EJCl2jk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Sgowlunl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ribGxCPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5EE6jnP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JA24TVDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XUuGBuQ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x6AqtCIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hg9QDBqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5bQdCiCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rRnbXRgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DZQFWOxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OMSsThZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tykwSlaw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G6NSCXvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kCs68pGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xa1csqtj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oZetIbWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kxQgXQOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7p4DwPaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nnRvf8OF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hi57PauG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GYuwVoLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_osi7gBjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xlNbgKrE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bPlgMsSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ToTJuXP6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BsBl3jAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k4PhwRSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i3QyYWMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O6ORVgZh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7g7bk96W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jufwSZHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MqnLGjc0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RDzEAtO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jnKVly4J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AEqorDIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mbYVjCwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sEJ5T9ZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3yyhY2ML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4PO6Nz90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TibQ24tU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bUYqTYE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ngPUtPIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SZbhEqsg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_43wzWFlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7WETABvg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vFdyNRgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jqMkANrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TPmUmvta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Te1aaPAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B5cIh5pE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mD9IzXJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HT7bOXkz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cb321uzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KKRWzRDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IKs62bYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vkAJgrxW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f2AfhINi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XvfPNpp0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LqawKBWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2wIInUIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uonLI4yp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_S51QmdCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L1uoW6Mk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3vx54RUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PsmVtNMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LVpLFhez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rKM67wxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZsszaDye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GQbsdThi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tF0Qiofn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AMidWWVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PH1sFFme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mGGxboUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z2jMiTxg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T5NrIhzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WuCvXVdz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T93FZARq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vh0d01Dt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qHn4tQgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Skj6QyRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iD3bQpkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z5gShRKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aWzH2jdw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nsBv7zB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DjQmPxTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nM0z4X9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ahUSDYKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_srUt5FMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HY9vsU4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2ZmsZwha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4UWOMCxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hpd8VV9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wfEbL3pB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HF5JO4Up_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XkR4dcFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xm3CFtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KxEUMr0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sbmF9GuF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nYJ2yYOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WbqrcWjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pECUAwDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1qh6nu8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jpaMLmKk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oWxfXW61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ayb8nIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bnpQBsKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_48fykbLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rxIMVW14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7nQzBKGY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HOhUh8Nm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fGW3ErXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tCz1uxnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sREI5qbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zumbgOOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jBh0Kzh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YGQ6qBDr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SOZQuDks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2jDlqv2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dyDORE99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IzEaegL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M1WPiQwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_61nkVSmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jTXJOqSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FXtZKsMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_byf4zQlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fD3Ckcvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mkOurOaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4XcUMFD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yssEoLKe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AJbg2aFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QREqYDAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_A1oOmAvz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TUPXcmRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ND4gzReP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oV4aTWjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DpWMp1sP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_suYNHIOA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yJedujsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fAu0SWTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bavDyRbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0GkxWIxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OuwszPb6_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_xwQq68k5;
  SignalLine sLine_R4ZCCfpf;
  SignalLine sLine_nftXhldO;
  SignalLine sLine_QTVS3zlb;
  SignalLine sLine_wVzFe3A5;
  SignalBiquad sBiquad_s_fB8t46dP;
  SignalLine sLine_y0b5ULk4;
  SignalLine sLine_spllSADz;
  SignalLine sLine_IQZuMiV2;
  SignalLine sLine_xzJVUKeL;
  SignalBiquad sBiquad_s_YHBxLEJE;
  SignalLine sLine_uiFswhpa;
  SignalLine sLine_8PaH7ACC;
  SignalLine sLine_Tf9LN3Fe;
  SignalLine sLine_XPZfroET;
  SignalLine sLine_vo9Jjnz9;
  SignalBiquad sBiquad_s_73KMs3pp;
  SignalLine sLine_bDn5AKXO;
  SignalLine sLine_VgNX9ncw;
  SignalLine sLine_H3eeqbEc;
  SignalLine sLine_UuncZiBo;
  SignalLine sLine_ctnrfAT1;
  SignalBiquad sBiquad_s_dU8GZIpL;
  SignalLine sLine_lCQraw1l;
  SignalLine sLine_EosRuq2Z;
  SignalLine sLine_Q6mA0Sy7;
  SignalLine sLine_pLGVrIIS;
  SignalBiquad sBiquad_s_0QLT9Pv8;
  SignalLine sLine_uGwzNEMM;
  SignalLine sLine_8tA9TQge;
  SignalLine sLine_3kKKUQPB;
  SignalLine sLine_qCPThttB;
  SignalLine sLine_mD1VSZbX;
  SignalBiquad sBiquad_s_FIhojla5;
  ControlVar cVar_sbpPCCGw;
  ControlVar cVar_cWo9gxkv;
  ControlVar cVar_nUVabuMa;
  ControlVar cVar_W6tFkCGx;
  ControlSlice cSlice_jUOeg1oo;
  ControlVar cVar_nnAOChJq;
  ControlVar cVar_gQYefG2P;
  ControlIf cIf_zTUlgBkL;
  ControlIf cIf_FcnPfWHC;
  ControlBinop cBinop_nHT79UaW;
  ControlBinop cBinop_yLqy64Xd;
  ControlBinop cBinop_wtttzPA0;
  ControlBinop cBinop_rhHORIJr;
  ControlBinop cBinop_lfR61gNI;
  ControlIf cIf_4h23LhVQ;
  ControlBinop cBinop_zonIE7VJ;
  ControlBinop cBinop_72JZMqxu;
  ControlBinop cBinop_HZ27tHd2;
  ControlBinop cBinop_WOKr0m7N;
  ControlBinop cBinop_9vqmrS5q;
  ControlVar cVar_m45ByE2z;
  ControlIf cIf_DR5Wgnrd;
  ControlIf cIf_T2Ze8rZv;
  ControlBinop cBinop_SyFGz9v3;
  ControlBinop cBinop_tZCcTELk;
  ControlBinop cBinop_p5qBQNv3;
  ControlBinop cBinop_PX7lzsbL;
  ControlBinop cBinop_n4iYPndy;
  ControlIf cIf_g4CHLw7I;
  ControlBinop cBinop_tZukKoFv;
  ControlBinop cBinop_4fDIOoWy;
  ControlBinop cBinop_gAbFo12w;
  ControlBinop cBinop_NPjButj1;
  ControlBinop cBinop_LPei48Pq;
  ControlVar cVar_z2jW8X3p;
  ControlIf cIf_Ac225Bxh;
  ControlIf cIf_CkeyUgsl;
  ControlBinop cBinop_N4afJPEd;
  ControlBinop cBinop_qx9tZ9hb;
  ControlBinop cBinop_hSCmdpZ9;
  ControlBinop cBinop_UhojmigP;
  ControlBinop cBinop_p6Envumk;
  ControlIf cIf_AZRqLQe2;
  ControlBinop cBinop_KBHRS9bU;
  ControlBinop cBinop_CtOl6QMx;
  ControlBinop cBinop_SlRW41Dn;
  ControlBinop cBinop_FlqJeSrD;
  ControlBinop cBinop_oEULgXzS;
  ControlIf cIf_hegu2akz;
  ControlSlice cSlice_RW0RPSn1;
  ControlVar cVar_E8T7HRpH;
  ControlSlice cSlice_fogOwRJ6;
  ControlVar cVar_3hfgpU3t;
  ControlSlice cSlice_atDDQZOv;
  ControlVar cVar_vQSOoHap;
  ControlSlice cSlice_TSCOfOd1;
  ControlVar cVar_hr2x1d1W;
  ControlBinop cBinop_NZ0pDPu5;
  ControlBinop cBinop_mhAJLhTY;
  ControlBinop cBinop_0G9jdtAi;
  ControlBinop cBinop_w7rCNmv3;
  ControlBinop cBinop_jsAX24cP;
  ControlBinop cBinop_O0y0WUp2;
  ControlBinop cBinop_aw7av0yF;
  ControlBinop cBinop_xq7mXJUl;
  ControlVar cVar_KAk8ODdU;
  ControlBinop cBinop_CSkvq3TD;
  ControlBinop cBinop_L6eOtBot;
  ControlBinop cBinop_Z1BfVlfm;
  ControlBinop cBinop_ti9FS5Kn;
  ControlBinop cBinop_TIXOoKw1;
  ControlBinop cBinop_zkLSjlLF;
  ControlBinop cBinop_cnrEq9hz;
  ControlBinop cBinop_RiAMLUm3;
  ControlVar cVar_l5DWwum2;
  ControlVar cVar_GzL67g1u;
  ControlBinop cBinop_tmYb5h1p;
  ControlBinop cBinop_Oc7l89XA;
  ControlBinop cBinop_jk5oO3PG;
  ControlBinop cBinop_3UryvCxN;
  ControlBinop cBinop_HEWLx4Le;
  ControlBinop cBinop_tMlUTZIc;
  ControlBinop cBinop_rG3SxUmX;
  ControlBinop cBinop_QFQtKCxB;
  ControlBinop cBinop_6Xskvlfj;
  ControlBinop cBinop_odpXx4hb;
  ControlBinop cBinop_W7PNY2GF;
  ControlBinop cBinop_uMqx4KWQ;
  ControlBinop cBinop_1snr4Bgw;
  ControlBinop cBinop_kXjXvJFI;
  ControlBinop cBinop_GGirUaFY;
  ControlBinop cBinop_qdrB5zU3;
  ControlBinop cBinop_BSkDaKzf;
  ControlBinop cBinop_VUTBUkgu;
  ControlBinop cBinop_7zZaOCR6;
  ControlBinop cBinop_DMIXYDPC;
  ControlVar cVar_dDfKPTFj;
  ControlVar cVar_w9urElia;
  ControlVar cVar_4us9VA1X;
  ControlBinop cBinop_87ucv1C9;
  ControlBinop cBinop_H7lHpK35;
  ControlBinop cBinop_710ODwYs;
  ControlBinop cBinop_gggjjuFp;
  ControlBinop cBinop_M4SFKHtH;
  ControlBinop cBinop_DzaDAzPj;
  ControlBinop cBinop_WbNaGn1v;
  ControlBinop cBinop_g4dcl8cy;
  ControlBinop cBinop_2AYVy6DK;
  ControlBinop cBinop_UYAXRNzs;
  ControlBinop cBinop_CImUBRBe;
  ControlBinop cBinop_pWBiV91c;
  ControlBinop cBinop_xFQPkvUK;
  ControlBinop cBinop_hI7C2XcG;
  ControlBinop cBinop_FwofrmTf;
  ControlBinop cBinop_hGKE2s0N;
  ControlBinop cBinop_VqtoBMhp;
  ControlBinop cBinop_tKvsM0Pn;
  ControlBinop cBinop_a9bCVOOV;
  ControlBinop cBinop_QWEcf4l9;
  ControlBinop cBinop_AFMzrp8H;
  ControlBinop cBinop_DgtPMMbr;
  ControlBinop cBinop_C9xAbKg9;
  ControlVar cVar_elYxWOC3;
  ControlVar cVar_BSCpoY7H;
  ControlVar cVar_6JwOcHEb;
  ControlBinop cBinop_UEiw3Lz0;
  ControlBinop cBinop_ASN6Vwnt;
  ControlBinop cBinop_c8NOb3xV;
  ControlBinop cBinop_LBigE7Ya;
  ControlBinop cBinop_FV8BP622;
  ControlBinop cBinop_unf865fb;
  ControlBinop cBinop_POQm0h9u;
  ControlBinop cBinop_49oxELmw;
  ControlBinop cBinop_Gvs09Kuq;
  ControlBinop cBinop_d6bBW83M;
  ControlBinop cBinop_VzQPVnO4;
  ControlBinop cBinop_4LSjC46c;
  SignalVarf sVarf_Xi2yLdY1;
  SignalVarf sVarf_Gbs2tjbJ;
  SignalVarf sVarf_V2cMVnti;
  ControlSlice cSlice_HQMnGgpf;
  ControlVar cVar_Br4Jg7yu;
  ControlVar cVar_T7X9QhEh;
  ControlIf cIf_jeN22Ah6;
  ControlIf cIf_rNlLTCoX;
  ControlBinop cBinop_GtUckfxQ;
  ControlBinop cBinop_yRngRHnJ;
  ControlBinop cBinop_fvRfRsnz;
  ControlBinop cBinop_p6pMyQPV;
  ControlBinop cBinop_6AF18NmQ;
  ControlIf cIf_TWbAucI7;
  ControlBinop cBinop_aqM3zEKb;
  ControlBinop cBinop_2EyxcWsK;
  ControlBinop cBinop_Ypxwnv5V;
  ControlBinop cBinop_t7v0g691;
  ControlBinop cBinop_gSoFGGPW;
  ControlVar cVar_rNY7SybR;
  ControlIf cIf_o3AK0O9J;
  ControlIf cIf_wd1NqYVt;
  ControlBinop cBinop_az2yH9Qp;
  ControlBinop cBinop_mlSUFpXt;
  ControlBinop cBinop_GzKqfsVm;
  ControlBinop cBinop_4sZZL9to;
  ControlBinop cBinop_piatTCP5;
  ControlIf cIf_SdJx2VsY;
  ControlBinop cBinop_hsnO3u9E;
  ControlBinop cBinop_mBkd4v0e;
  ControlBinop cBinop_3ddvQpFm;
  ControlBinop cBinop_uAeNsrD2;
  ControlBinop cBinop_OHYW1hNr;
  ControlVar cVar_M3so6w36;
  ControlIf cIf_Pc8u0hIX;
  ControlIf cIf_R580Dnqo;
  ControlBinop cBinop_qxO7qwl0;
  ControlBinop cBinop_2t8s8jxG;
  ControlBinop cBinop_rUwS4NTH;
  ControlBinop cBinop_As364Y5E;
  ControlBinop cBinop_ORXaktoW;
  ControlIf cIf_ez1mpYHk;
  ControlBinop cBinop_YdnVsZuZ;
  ControlBinop cBinop_7v7EYEq5;
  ControlBinop cBinop_sBy6LxZj;
  ControlBinop cBinop_wAbnv0NA;
  ControlBinop cBinop_40Jb2wMV;
  ControlIf cIf_oAvwWFyA;
  ControlSlice cSlice_yYEKLX4B;
  ControlVar cVar_uzeBdUDX;
  ControlSlice cSlice_zzlKqhZg;
  ControlVar cVar_o1UnoAVD;
  ControlSlice cSlice_BUSsijos;
  ControlVar cVar_AscovyCN;
  ControlSlice cSlice_hE4ipsRe;
  ControlVar cVar_uulvHMyW;
  ControlBinop cBinop_gS008QvU;
  ControlBinop cBinop_qXLsG593;
  ControlBinop cBinop_pKpdxd4K;
  ControlBinop cBinop_fzawCbDS;
  ControlBinop cBinop_lZK6F3W7;
  ControlBinop cBinop_uqu45Wb3;
  ControlBinop cBinop_YNtHPbAa;
  ControlBinop cBinop_0lIpxNXB;
  ControlVar cVar_Tm6Kshoh;
  ControlBinop cBinop_1jn3QTOG;
  ControlBinop cBinop_XDs28JwT;
  ControlBinop cBinop_juxC5iJh;
  ControlBinop cBinop_JdU9Wt54;
  ControlBinop cBinop_SjHLRRn2;
  ControlBinop cBinop_eqEQ1gjN;
  ControlBinop cBinop_BtmS0Zrs;
  ControlBinop cBinop_RFKifFLE;
  ControlVar cVar_koEBCmiB;
  ControlVar cVar_Zspa6EZe;
  ControlBinop cBinop_amL7Ud1F;
  ControlBinop cBinop_p0mCy4vR;
  ControlBinop cBinop_Fy499Tnx;
  ControlBinop cBinop_UMMDphwg;
  ControlBinop cBinop_IjH85kEb;
  ControlBinop cBinop_uoRsfrTY;
  ControlBinop cBinop_yBmjV1sP;
  ControlBinop cBinop_lFZtjTWt;
  ControlBinop cBinop_74AJzyVY;
  ControlBinop cBinop_pCIy5uO8;
  ControlBinop cBinop_5Dcrrlnd;
  ControlBinop cBinop_Gjkvc0oJ;
  ControlBinop cBinop_W8mGZLm7;
  ControlBinop cBinop_MluBFVOc;
  ControlBinop cBinop_WtPCcl5X;
  ControlBinop cBinop_qoaOABPT;
  ControlBinop cBinop_gLULnQjk;
  ControlBinop cBinop_bOqp5u4N;
  ControlBinop cBinop_PCgrtIHK;
  ControlBinop cBinop_KZsxynh6;
  ControlVar cVar_glX11rbY;
  ControlVar cVar_s3Yvbn4B;
  ControlVar cVar_5EJCl2jk;
  ControlBinop cBinop_Hg9QDBqO;
  ControlBinop cBinop_5bQdCiCe;
  ControlBinop cBinop_rRnbXRgt;
  ControlBinop cBinop_OMSsThZ6;
  ControlBinop cBinop_tykwSlaw;
  ControlBinop cBinop_G6NSCXvZ;
  ControlBinop cBinop_kCs68pGE;
  ControlBinop cBinop_Xa1csqtj;
  ControlBinop cBinop_RDzEAtO7;
  ControlBinop cBinop_AEqorDIr;
  ControlBinop cBinop_mbYVjCwg;
  ControlBinop cBinop_4PO6Nz90;
  ControlBinop cBinop_TibQ24tU;
  ControlBinop cBinop_bUYqTYE6;
  ControlBinop cBinop_ngPUtPIt;
  ControlBinop cBinop_SZbhEqsg;
  ControlBinop cBinop_7WETABvg;
  ControlBinop cBinop_jqMkANrc;
  ControlBinop cBinop_TPmUmvta;
  ControlBinop cBinop_B5cIh5pE;
  ControlBinop cBinop_mD9IzXJO;
  ControlBinop cBinop_HT7bOXkz;
  ControlBinop cBinop_KKRWzRDP;
  ControlVar cVar_IKs62bYO;
  ControlVar cVar_vkAJgrxW;
  ControlVar cVar_f2AfhINi;
  ControlBinop cBinop_3vx54RUj;
  ControlBinop cBinop_PsmVtNMP;
  ControlBinop cBinop_LVpLFhez;
  ControlBinop cBinop_ZsszaDye;
  ControlBinop cBinop_GQbsdThi;
  ControlBinop cBinop_tF0Qiofn;
  ControlBinop cBinop_AMidWWVp;
  ControlBinop cBinop_PH1sFFme;
  ControlBinop cBinop_mGGxboUc;
  ControlBinop cBinop_nsBv7zB2;
  ControlBinop cBinop_nM0z4X9v;
  ControlBinop cBinop_ahUSDYKg;
  SignalVarf sVarf_uYjoKaUb;
  SignalVarf sVarf_imdt7unY;
  SignalVarf sVarf_qM4P4pBb;
  SignalVarf sVarf_hmSBeQ4E;
  SignalVarf sVarf_zkzUm6K2;
  SignalVarf sVarf_cQy3V7im;
  SignalVarf sVarf_jtC7raYm;
  SignalVarf sVarf_jMnYOXsR;
  SignalVarf sVarf_bhFdefn5;
  ControlVar cVar_srUt5FMH;
  ControlVar cVar_HY9vsU4N;
  ControlBinop cBinop_XkR4dcFO;
  ControlBinop cBinop_9xm3CFtV;
  ControlBinop cBinop_KxEUMr0z;
  ControlBinop cBinop_nYJ2yYOd;
  ControlBinop cBinop_WbqrcWjV;
  ControlBinop cBinop_pECUAwDu;
  ControlBinop cBinop_1qh6nu8f;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
