/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_xwQq68k5);
  numBytes += sLine_init(&sLine_R4ZCCfpf);
  numBytes += sLine_init(&sLine_nftXhldO);
  numBytes += sLine_init(&sLine_QTVS3zlb);
  numBytes += sLine_init(&sLine_wVzFe3A5);
  numBytes += sBiquad_init(&sBiquad_s_fB8t46dP);
  numBytes += sLine_init(&sLine_y0b5ULk4);
  numBytes += sLine_init(&sLine_spllSADz);
  numBytes += sLine_init(&sLine_IQZuMiV2);
  numBytes += sLine_init(&sLine_xzJVUKeL);
  numBytes += sBiquad_init(&sBiquad_s_YHBxLEJE);
  numBytes += sLine_init(&sLine_uiFswhpa);
  numBytes += sLine_init(&sLine_8PaH7ACC);
  numBytes += sLine_init(&sLine_Tf9LN3Fe);
  numBytes += sLine_init(&sLine_XPZfroET);
  numBytes += sLine_init(&sLine_vo9Jjnz9);
  numBytes += sBiquad_init(&sBiquad_s_73KMs3pp);
  numBytes += sLine_init(&sLine_bDn5AKXO);
  numBytes += sLine_init(&sLine_VgNX9ncw);
  numBytes += sLine_init(&sLine_H3eeqbEc);
  numBytes += sLine_init(&sLine_UuncZiBo);
  numBytes += sLine_init(&sLine_ctnrfAT1);
  numBytes += sBiquad_init(&sBiquad_s_dU8GZIpL);
  numBytes += sLine_init(&sLine_lCQraw1l);
  numBytes += sLine_init(&sLine_EosRuq2Z);
  numBytes += sLine_init(&sLine_Q6mA0Sy7);
  numBytes += sLine_init(&sLine_pLGVrIIS);
  numBytes += sBiquad_init(&sBiquad_s_0QLT9Pv8);
  numBytes += sLine_init(&sLine_uGwzNEMM);
  numBytes += sLine_init(&sLine_8tA9TQge);
  numBytes += sLine_init(&sLine_3kKKUQPB);
  numBytes += sLine_init(&sLine_qCPThttB);
  numBytes += sLine_init(&sLine_mD1VSZbX);
  numBytes += sBiquad_init(&sBiquad_s_FIhojla5);
  numBytes += cVar_init_f(&cVar_sbpPCCGw, 0.0f);
  numBytes += cVar_init_f(&cVar_cWo9gxkv, 0.0f);
  numBytes += cVar_init_f(&cVar_nUVabuMa, 0.0f);
  numBytes += cVar_init_f(&cVar_W6tFkCGx, 0.0f);
  numBytes += cSlice_init(&cSlice_jUOeg1oo, 1, -1);
  numBytes += cVar_init_f(&cVar_nnAOChJq, 1337.0f);
  numBytes += cVar_init_f(&cVar_gQYefG2P, 0.0f);
  numBytes += cIf_init(&cIf_zTUlgBkL, false);
  numBytes += cIf_init(&cIf_FcnPfWHC, false);
  numBytes += cBinop_init(&cBinop_nHT79UaW, 0.0f); // __pow
  numBytes += cIf_init(&cIf_4h23LhVQ, false);
  numBytes += cBinop_init(&cBinop_HZ27tHd2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WOKr0m7N, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9vqmrS5q, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_m45ByE2z, 0.0f);
  numBytes += cIf_init(&cIf_DR5Wgnrd, false);
  numBytes += cIf_init(&cIf_T2Ze8rZv, false);
  numBytes += cBinop_init(&cBinop_SyFGz9v3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_g4CHLw7I, false);
  numBytes += cBinop_init(&cBinop_gAbFo12w, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_NPjButj1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_LPei48Pq, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_z2jW8X3p, 0.0f);
  numBytes += cIf_init(&cIf_Ac225Bxh, false);
  numBytes += cIf_init(&cIf_CkeyUgsl, false);
  numBytes += cBinop_init(&cBinop_N4afJPEd, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AZRqLQe2, false);
  numBytes += cBinop_init(&cBinop_SlRW41Dn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_FlqJeSrD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_oEULgXzS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_hegu2akz, false);
  numBytes += cSlice_init(&cSlice_RW0RPSn1, 1, -1);
  numBytes += cVar_init_f(&cVar_E8T7HRpH, 0.0f);
  numBytes += cSlice_init(&cSlice_fogOwRJ6, 1, -1);
  numBytes += cVar_init_f(&cVar_3hfgpU3t, 0.0f);
  numBytes += cSlice_init(&cSlice_atDDQZOv, 1, -1);
  numBytes += cVar_init_f(&cVar_vQSOoHap, 0.0f);
  numBytes += cSlice_init(&cSlice_TSCOfOd1, 1, -1);
  numBytes += cVar_init_f(&cVar_hr2x1d1W, 0.313f);
  numBytes += cBinop_init(&cBinop_mhAJLhTY, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_0G9jdtAi, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_KAk8ODdU, 0.0f);
  numBytes += cVar_init_f(&cVar_l5DWwum2, 1337.0f);
  numBytes += cVar_init_f(&cVar_GzL67g1u, 0.3f);
  numBytes += cBinop_init(&cBinop_Oc7l89XA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HEWLx4Le, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tMlUTZIc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rG3SxUmX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QFQtKCxB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6Xskvlfj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W7PNY2GF, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_uMqx4KWQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dDfKPTFj, 0.0f);
  numBytes += cVar_init_f(&cVar_w9urElia, 1337.0f);
  numBytes += cVar_init_f(&cVar_4us9VA1X, 0.313f);
  numBytes += cBinop_init(&cBinop_H7lHpK35, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M4SFKHtH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DzaDAzPj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WbNaGn1v, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_g4dcl8cy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UYAXRNzs, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CImUBRBe, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_elYxWOC3, 0.0f);
  numBytes += cVar_init_f(&cVar_BSCpoY7H, 1037.0f);
  numBytes += cVar_init_f(&cVar_6JwOcHEb, 0.4f);
  numBytes += cBinop_init(&cBinop_ASN6Vwnt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FV8BP622, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_unf865fb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_POQm0h9u, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_49oxELmw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Gvs09Kuq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Xi2yLdY1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gbs2tjbJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V2cMVnti, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_HQMnGgpf, 1, -1);
  numBytes += cVar_init_f(&cVar_Br4Jg7yu, 1337.0f);
  numBytes += cVar_init_f(&cVar_T7X9QhEh, 0.0f);
  numBytes += cIf_init(&cIf_jeN22Ah6, false);
  numBytes += cIf_init(&cIf_rNlLTCoX, false);
  numBytes += cBinop_init(&cBinop_GtUckfxQ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TWbAucI7, false);
  numBytes += cBinop_init(&cBinop_Ypxwnv5V, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_t7v0g691, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_gSoFGGPW, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_rNY7SybR, 0.0f);
  numBytes += cIf_init(&cIf_o3AK0O9J, false);
  numBytes += cIf_init(&cIf_wd1NqYVt, false);
  numBytes += cBinop_init(&cBinop_az2yH9Qp, 0.0f); // __pow
  numBytes += cIf_init(&cIf_SdJx2VsY, false);
  numBytes += cBinop_init(&cBinop_3ddvQpFm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_uAeNsrD2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OHYW1hNr, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_M3so6w36, 0.0f);
  numBytes += cIf_init(&cIf_Pc8u0hIX, false);
  numBytes += cIf_init(&cIf_R580Dnqo, false);
  numBytes += cBinop_init(&cBinop_qxO7qwl0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ez1mpYHk, false);
  numBytes += cBinop_init(&cBinop_sBy6LxZj, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wAbnv0NA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_40Jb2wMV, -15.0f); // __eq
  numBytes += cIf_init(&cIf_oAvwWFyA, false);
  numBytes += cSlice_init(&cSlice_yYEKLX4B, 1, -1);
  numBytes += cVar_init_f(&cVar_uzeBdUDX, 0.0f);
  numBytes += cSlice_init(&cSlice_zzlKqhZg, 1, -1);
  numBytes += cVar_init_f(&cVar_o1UnoAVD, 0.0f);
  numBytes += cSlice_init(&cSlice_BUSsijos, 1, -1);
  numBytes += cVar_init_f(&cVar_AscovyCN, 0.0f);
  numBytes += cSlice_init(&cSlice_hE4ipsRe, 1, -1);
  numBytes += cVar_init_f(&cVar_uulvHMyW, 0.313f);
  numBytes += cBinop_init(&cBinop_qXLsG593, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pKpdxd4K, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Tm6Kshoh, 0.0f);
  numBytes += cVar_init_f(&cVar_koEBCmiB, 1337.0f);
  numBytes += cVar_init_f(&cVar_Zspa6EZe, 0.3f);
  numBytes += cBinop_init(&cBinop_p0mCy4vR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IjH85kEb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uoRsfrTY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yBmjV1sP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lFZtjTWt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_74AJzyVY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5Dcrrlnd, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Gjkvc0oJ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_glX11rbY, 0.0f);
  numBytes += cVar_init_f(&cVar_s3Yvbn4B, 1337.0f);
  numBytes += cVar_init_f(&cVar_5EJCl2jk, 0.313f);
  numBytes += cBinop_init(&cBinop_5bQdCiCe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tykwSlaw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G6NSCXvZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kCs68pGE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Xa1csqtj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AEqorDIr, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mbYVjCwg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IKs62bYO, 0.0f);
  numBytes += cVar_init_f(&cVar_vkAJgrxW, 1037.0f);
  numBytes += cVar_init_f(&cVar_f2AfhINi, 0.4f);
  numBytes += cBinop_init(&cBinop_PsmVtNMP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GQbsdThi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tF0Qiofn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AMidWWVp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PH1sFFme, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mGGxboUc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_uYjoKaUb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_imdt7unY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qM4P4pBb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hmSBeQ4E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zkzUm6K2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cQy3V7im, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jtC7raYm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jMnYOXsR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bhFdefn5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_srUt5FMH, 5705.6f);
  numBytes += cVar_init_f(&cVar_HY9vsU4N, 313.3f);
  numBytes += cBinop_init(&cBinop_XkR4dcFO, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_9xm3CFtV, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_KxEUMr0z, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HOhUh8Nm_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tCz1uxnH_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fGW3ErXT_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OuwszPb6_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jBh0Kzh1_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YGQ6qBDr_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sREI5qbO_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zumbgOOs_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SOZQuDks_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M1WPiQwE_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IzEaegL3_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dyDORE99_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FXtZKsMZ_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jTXJOqSy_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_61nkVSmg_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mkOurOaR_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fD3Ckcvd_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_byf4zQlL_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AJbg2aFT_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QREqYDAw_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4XcUMFD4_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yssEoLKe_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A1oOmAvz_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oV4aTWjE_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ND4gzReP_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TUPXcmRb_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yJedujsH_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_suYNHIOA_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DpWMp1sP_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0GkxWIxQ_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bavDyRbY_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fAu0SWTk_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2jDlqv2f_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_sbpPCCGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jpaMLmKk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_cWo9gxkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oWxfXW61_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_nUVabuMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7ayb8nIF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_W6tFkCGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnpQBsKd_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HF5JO4Up_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfEbL3pB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hpd8VV9a_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_EX13jqKT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jUOeg1oo, 0, m, &cSlice_jUOeg1oo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nWGFWw8I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_jUOeg1oo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dHRSOFEp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dHRSOFEp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_nnAOChJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dHRSOFEp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_dHRSOFEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sREI5qbO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gQYefG2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zonIE7VJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_zTUlgBkL, 0, m, &cIf_zTUlgBkL_sendMessage);
}

void Heavy_WSTD_EQ::cIf_zTUlgBkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_72JZMqxu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_FcnPfWHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_UEwCzepf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_rhHORIJr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_NS8Xjm25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nHT79UaW, HV_BINOP_POW, 0, m, &cBinop_nHT79UaW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nHT79UaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4h23LhVQ, 0, m, &cIf_4h23LhVQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yLqy64Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lfR61gNI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PRE3iUQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wtttzPA0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_B1SVvVfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FcnPfWHC, 0, m, &cIf_FcnPfWHC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wtttzPA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FcnPfWHC, 1, m, &cIf_FcnPfWHC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rhHORIJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yLqy64Xd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_UEwCzepf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4h23LhVQ, 0, m, &cIf_4h23LhVQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lfR61gNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nHT79UaW, HV_BINOP_POW, 1, m, &cBinop_nHT79UaW_sendMessage);
  cMsg_NS8Xjm25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_4h23LhVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Xi2yLdY1, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_zonIE7VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zTUlgBkL, 1, m, &cIf_zTUlgBkL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_72JZMqxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOKr0m7N, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WOKr0m7N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9vqmrS5q, HV_BINOP_EQ, 1, m, &cBinop_9vqmrS5q_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_0TMODZrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HZ27tHd2, HV_BINOP_ADD, 0, m, &cBinop_HZ27tHd2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HZ27tHd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PRE3iUQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B1SVvVfc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WOKr0m7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4h23LhVQ, 1, m, &cIf_4h23LhVQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9vqmrS5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sbYatqaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_sbYatqaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xi2yLdY1, m);
}

void Heavy_WSTD_EQ::cCast_A4vU5g0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gQYefG2P, 0, m, &cVar_gQYefG2P_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2Mi4uZ3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0TMODZrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_oda20OHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HZ27tHd2, HV_BINOP_ADD, 1, m, &cBinop_HZ27tHd2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WOKr0m7N, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WOKr0m7N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9vqmrS5q, HV_BINOP_EQ, 0, m, &cBinop_9vqmrS5q_sendMessage);
}

void Heavy_WSTD_EQ::cVar_m45ByE2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tZukKoFv_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_DR5Wgnrd, 0, m, &cIf_DR5Wgnrd_sendMessage);
}

void Heavy_WSTD_EQ::cIf_DR5Wgnrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4fDIOoWy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_T2Ze8rZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_I6U7iOhu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PX7lzsbL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_raYd6ZiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SyFGz9v3, HV_BINOP_POW, 0, m, &cBinop_SyFGz9v3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SyFGz9v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g4CHLw7I, 0, m, &cIf_g4CHLw7I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tZCcTELk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_n4iYPndy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3Pc4ILi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_p5qBQNv3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NkupUPQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2Ze8rZv, 0, m, &cIf_T2Ze8rZv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p5qBQNv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T2Ze8rZv, 1, m, &cIf_T2Ze8rZv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PX7lzsbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_tZCcTELk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_I6U7iOhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_g4CHLw7I, 0, m, &cIf_g4CHLw7I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_n4iYPndy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SyFGz9v3, HV_BINOP_POW, 1, m, &cBinop_SyFGz9v3_sendMessage);
  cMsg_raYd6ZiO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_g4CHLw7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d6bBW83M_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VzQPVnO4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_4LSjC46c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_tZukKoFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DR5Wgnrd, 1, m, &cIf_DR5Wgnrd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4fDIOoWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NPjButj1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NPjButj1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LPei48Pq, HV_BINOP_EQ, 1, m, &cBinop_LPei48Pq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_0c31vY3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gAbFo12w, HV_BINOP_ADD, 0, m, &cBinop_gAbFo12w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gAbFo12w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Pc4ILi2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NkupUPQI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NPjButj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g4CHLw7I, 1, m, &cIf_g4CHLw7I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LPei48Pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QWGFFHdq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QWGFFHdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d6bBW83M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VzQPVnO4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_4LSjC46c_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zue9kSr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0c31vY3i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_pF5kpmu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gAbFo12w, HV_BINOP_ADD, 1, m, &cBinop_gAbFo12w_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NPjButj1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_NPjButj1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LPei48Pq, HV_BINOP_EQ, 0, m, &cBinop_LPei48Pq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4AK04kFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m45ByE2z, 0, m, &cVar_m45ByE2z_sendMessage);
}

void Heavy_WSTD_EQ::cVar_z2jW8X3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KBHRS9bU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Ac225Bxh, 0, m, &cIf_Ac225Bxh_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Ac225Bxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CtOl6QMx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_CkeyUgsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_s4Ql850j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UhojmigP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_xfLAXTBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N4afJPEd, HV_BINOP_POW, 0, m, &cBinop_N4afJPEd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_N4afJPEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZRqLQe2, 0, m, &cIf_AZRqLQe2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qx9tZ9hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_p6Envumk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oI8yHVBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CkeyUgsl, 0, m, &cIf_CkeyUgsl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cP1HnOGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hSCmdpZ9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hSCmdpZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CkeyUgsl, 1, m, &cIf_CkeyUgsl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UhojmigP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qx9tZ9hb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_s4Ql850j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AZRqLQe2, 0, m, &cIf_AZRqLQe2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p6Envumk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N4afJPEd, HV_BINOP_POW, 1, m, &cBinop_N4afJPEd_sendMessage);
  cMsg_xfLAXTBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_AZRqLQe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_V2cMVnti, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_KBHRS9bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ac225Bxh, 1, m, &cIf_Ac225Bxh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CtOl6QMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FlqJeSrD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_FlqJeSrD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oEULgXzS, HV_BINOP_EQ, 1, m, &cBinop_oEULgXzS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_YBp1kKgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlRW41Dn, HV_BINOP_ADD, 0, m, &cBinop_SlRW41Dn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SlRW41Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cP1HnOGL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oI8yHVBC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FlqJeSrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZRqLQe2, 1, m, &cIf_AZRqLQe2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oEULgXzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ywxsZrPf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ywxsZrPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_V2cMVnti, m);
}

void Heavy_WSTD_EQ::cCast_2qXmL8SH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlRW41Dn, HV_BINOP_ADD, 1, m, &cBinop_SlRW41Dn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FlqJeSrD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_FlqJeSrD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oEULgXzS, HV_BINOP_EQ, 0, m, &cBinop_oEULgXzS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2TbpiJuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z2jW8X3p, 0, m, &cVar_z2jW8X3p_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qAlZcnzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YBp1kKgW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_hegu2akz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Gbs2tjbJ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_MmrXYs3Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RW0RPSn1, 0, m, &cSlice_RW0RPSn1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BXCnsDw0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_RW0RPSn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_InBNuTcj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_InBNuTcj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_E8T7HRpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_InBNuTcj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_InBNuTcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jBh0Kzh1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_BXCnsDw0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fogOwRJ6, 0, m, &cSlice_fogOwRJ6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EX13jqKT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_fogOwRJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YruIuSAi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YruIuSAi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_3hfgpU3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YruIuSAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_YruIuSAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SOZQuDks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_nWGFWw8I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_atDDQZOv, 0, m, &cSlice_atDDQZOv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XfH6UFi4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_atDDQZOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nMc0neb2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nMc0neb2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vQSOoHap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nMc0neb2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_nMc0neb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YGQ6qBDr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_XfH6UFi4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TSCOfOd1, 0, m, &cSlice_TSCOfOd1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_TSCOfOd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xYefeCNP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xYefeCNP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_hr2x1d1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xYefeCNP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_xYefeCNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zumbgOOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kTuP3iYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xwQq68k5, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0hoPHbq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R4ZCCfpf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_nH0Mwskq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nftXhldO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rVLI4adc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QTVS3zlb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_yG317xl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wVzFe3A5, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_NXFD6YmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gak5Elnz_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_gak5Elnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mhAJLhTY, HV_BINOP_DIVIDE, 1, m, &cBinop_mhAJLhTY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BNes3nef_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_6YorC2XT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_NZ0pDPu5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_P8GRosQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_6YorC2XT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NZ0pDPu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mhAJLhTY, HV_BINOP_DIVIDE, 0, m, &cBinop_mhAJLhTY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BNes3nef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P8GRosQ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mhAJLhTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0G9jdtAi, HV_BINOP_MULTIPLY, 1, m, &cBinop_0G9jdtAi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0G9jdtAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2pQ2sEH9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pxa919m6_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_sJ9y5uzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U6a3ppET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_N3DyCE3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oBvUm5Di_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_w7rCNmv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_jsAX24cP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jsAX24cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0G9jdtAi, HV_BINOP_MULTIPLY, 0, m, &cBinop_0G9jdtAi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O0y0WUp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_aw7av0yF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aw7av0yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wc1ooVxt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xq7mXJUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KAk8ODdU, 1, m, &cVar_KAk8ODdU_sendMessage);
}

void Heavy_WSTD_EQ::cVar_KAk8ODdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_egeh4Op6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CSkvq3TD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HEWLx4Le, HV_BINOP_MULTIPLY, 1, m, &cBinop_HEWLx4Le_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_L6eOtBot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CSkvq3TD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z1BfVlfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ti9FS5Kn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ti9FS5Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMlUTZIc, HV_BINOP_MULTIPLY, 1, m, &cBinop_tMlUTZIc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TIXOoKw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rG3SxUmX, HV_BINOP_MULTIPLY, 1, m, &cBinop_rG3SxUmX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zkLSjlLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TIXOoKw1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cnrEq9hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFQtKCxB, HV_BINOP_MULTIPLY, 1, m, &cBinop_QFQtKCxB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_V7QN492f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RiAMLUm3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RiAMLUm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Xskvlfj, HV_BINOP_MULTIPLY, 1, m, &cBinop_6Xskvlfj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_l5DWwum2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EDKqcxQk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_w7rCNmv3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4b5Mh0cP_sendMessage);
}

void Heavy_WSTD_EQ::cVar_GzL67g1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_O0y0WUp2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Pxa919m6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_N3DyCE3E_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2pQ2sEH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_sJ9y5uzx_sendMessage);
}

void Heavy_WSTD_EQ::cSend_U6a3ppET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dyDORE99_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_oBvUm5Di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IzEaegL3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ujZTFx79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M1WPiQwE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Wc1ooVxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tmYb5h1p_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tmYb5h1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oc7l89XA, HV_BINOP_MULTIPLY, 1, m, &cBinop_Oc7l89XA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Oc7l89XA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jk5oO3PG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jk5oO3PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ujZTFx79_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_egeh4Op6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3UryvCxN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3UryvCxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7LUbn4ml_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SflR5C4s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y9SADpU2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ndI8pkD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9lBbxMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVTAW1t3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HEWLx4Le_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kTuP3iYb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tMlUTZIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0hoPHbq5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rG3SxUmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nH0Mwskq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QFQtKCxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rVLI4adc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6Xskvlfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yG317xl4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_p2ZS68wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GzL67g1u, 1, m, &cVar_GzL67g1u_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wfSJarCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l5DWwum2, 0, m, &cVar_l5DWwum2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GVTAW1t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HEWLx4Le, HV_BINOP_MULTIPLY, 0, m, &cBinop_HEWLx4Le_sendMessage);
}

void Heavy_WSTD_EQ::cCast_y9SADpU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFQtKCxB, HV_BINOP_MULTIPLY, 0, m, &cBinop_QFQtKCxB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V9lBbxMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tMlUTZIc, HV_BINOP_MULTIPLY, 0, m, &cBinop_tMlUTZIc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SflR5C4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Xskvlfj, HV_BINOP_MULTIPLY, 0, m, &cBinop_6Xskvlfj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7ndI8pkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rG3SxUmX, HV_BINOP_MULTIPLY, 0, m, &cBinop_rG3SxUmX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7LUbn4ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_4b5Mh0cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KAk8ODdU, 0, m, &cVar_KAk8ODdU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EDKqcxQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GzL67g1u, 0, m, &cVar_GzL67g1u_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wQ1YhmcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y0b5ULk4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pj4oPJXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_spllSADz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4CedhzbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IQZuMiV2, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_6hPk3Lwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xzJVUKeL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qRk6ITuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vWwQlGFt_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_vWwQlGFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W7PNY2GF, HV_BINOP_DIVIDE, 1, m, &cBinop_W7PNY2GF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0B9LNWRW_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_fSng4kbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_odpXx4hb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bb1yOVlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fSng4kbJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_odpXx4hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W7PNY2GF, HV_BINOP_DIVIDE, 0, m, &cBinop_W7PNY2GF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0B9LNWRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bb1yOVlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_W7PNY2GF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uMqx4KWQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_uMqx4KWQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uMqx4KWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xjqfUQag_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jpIz2EWu_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_jsgdlFAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xc1rt4Gb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_0RMuyQmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0mTN9Z2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1snr4Bgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_kXjXvJFI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kXjXvJFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uMqx4KWQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_uMqx4KWQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GGirUaFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qdrB5zU3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qdrB5zU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L15I9Kfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BSkDaKzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzaDAzPj, HV_BINOP_MULTIPLY, 1, m, &cBinop_DzaDAzPj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VUTBUkgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dDfKPTFj, 1, m, &cVar_dDfKPTFj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7zZaOCR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WbNaGn1v, HV_BINOP_MULTIPLY, 1, m, &cBinop_WbNaGn1v_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zhJYhF8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DMIXYDPC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DMIXYDPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4dcl8cy, HV_BINOP_MULTIPLY, 1, m, &cBinop_g4dcl8cy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_dDfKPTFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fFveFZPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_w9urElia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oyvnvidM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_1snr4Bgw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w1Ro9K08_sendMessage);
}

void Heavy_WSTD_EQ::cVar_4us9VA1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GGirUaFY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xjqfUQag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_jsgdlFAi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jpIz2EWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0RMuyQmD_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Xc1rt4Gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_61nkVSmg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_0mTN9Z2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jTXJOqSy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_86xvw9vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FXtZKsMZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_L15I9Kfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_87ucv1C9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_87ucv1C9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H7lHpK35, HV_BINOP_MULTIPLY, 1, m, &cBinop_H7lHpK35_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H7lHpK35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_710ODwYs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_710ODwYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_86xvw9vW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_fFveFZPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gggjjuFp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gggjjuFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0HcCXn6b_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Pg78DI8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lTCoRNK5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sEPKP3d0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M4SFKHtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wQ1YhmcC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DzaDAzPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pj4oPJXq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WbNaGn1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4CedhzbX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_g4dcl8cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6hPk3Lwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_EMC3MmJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4us9VA1X, 1, m, &cVar_4us9VA1X_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BGxe1VUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w9urElia, 0, m, &cVar_w9urElia_sendMessage);
}

void Heavy_WSTD_EQ::cCast_w1Ro9K08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dDfKPTFj, 0, m, &cVar_dDfKPTFj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oyvnvidM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4us9VA1X, 0, m, &cVar_4us9VA1X_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lTCoRNK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzaDAzPj, HV_BINOP_MULTIPLY, 0, m, &cBinop_DzaDAzPj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0Pg78DI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WbNaGn1v, HV_BINOP_MULTIPLY, 0, m, &cBinop_WbNaGn1v_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sEPKP3d0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M4SFKHtH, HV_BINOP_MULTIPLY, 0, m, &cBinop_M4SFKHtH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0HcCXn6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4dcl8cy, HV_BINOP_MULTIPLY, 0, m, &cBinop_g4dcl8cy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ndfFT7ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uiFswhpa, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_2cCDzd66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8PaH7ACC, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7GlDymp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tf9LN3Fe, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BxqtJXVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XPZfroET, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WVIoi2oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vo9Jjnz9, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GGOsaSDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8J8uD4gm_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_8J8uD4gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYAXRNzs, HV_BINOP_DIVIDE, 1, m, &cBinop_UYAXRNzs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HJEvf4YB_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_oLXCsvQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2AYVy6DK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Q6wDizef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oLXCsvQ9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2AYVy6DK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYAXRNzs, HV_BINOP_DIVIDE, 0, m, &cBinop_UYAXRNzs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HJEvf4YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q6wDizef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UYAXRNzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CImUBRBe, HV_BINOP_MULTIPLY, 1, m, &cBinop_CImUBRBe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CImUBRBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KFrZQdAf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vgPBIIIK_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_SAXUhANK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_s0IAc3Jh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_if5d1fJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JvWG86lF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pWBiV91c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xFQPkvUK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xFQPkvUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CImUBRBe, HV_BINOP_MULTIPLY, 0, m, &cBinop_CImUBRBe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hI7C2XcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_FwofrmTf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FwofrmTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6VsdUIsC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hGKE2s0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FV8BP622, HV_BINOP_MULTIPLY, 1, m, &cBinop_FV8BP622_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fsY5CSSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VqtoBMhp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VqtoBMhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hGKE2s0N_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9cYcq3JV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tKvsM0Pn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tKvsM0Pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_unf865fb, HV_BINOP_MULTIPLY, 1, m, &cBinop_unf865fb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a9bCVOOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POQm0h9u, HV_BINOP_MULTIPLY, 1, m, &cBinop_POQm0h9u_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DmoxZ5WB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QWEcf4l9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QWEcf4l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_a9bCVOOV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AFMzrp8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_elYxWOC3, 1, m, &cVar_elYxWOC3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DgtPMMbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_49oxELmw, HV_BINOP_MULTIPLY, 1, m, &cBinop_49oxELmw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_OJ7X0xIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_C9xAbKg9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C9xAbKg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gvs09Kuq, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gvs09Kuq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_elYxWOC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_agM27UkR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_BSCpoY7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iZjaWRHi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_pWBiV91c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GommmiGl_sendMessage);
}

void Heavy_WSTD_EQ::cVar_6JwOcHEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hI7C2XcG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KFrZQdAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_SAXUhANK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vgPBIIIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_if5d1fJu_sendMessage);
}

void Heavy_WSTD_EQ::cSend_s0IAc3Jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_byf4zQlL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JvWG86lF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fD3Ckcvd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ybghOLLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mkOurOaR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6VsdUIsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UEiw3Lz0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UEiw3Lz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ASN6Vwnt, HV_BINOP_MULTIPLY, 1, m, &cBinop_ASN6Vwnt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ASN6Vwnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_c8NOb3xV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c8NOb3xV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ybghOLLr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_agM27UkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LBigE7Ya_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LBigE7Ya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9dgFK2Uw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LYsLnDgN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SScxZBiE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xM4dDsXL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CrvLiuVF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TqVFkzcR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FV8BP622_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ndfFT7ii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_unf865fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2cCDzd66_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_POQm0h9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7GlDymp6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_49oxELmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BxqtJXVH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Gvs09Kuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WVIoi2oq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_jF2wZamD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6JwOcHEb, 1, m, &cVar_6JwOcHEb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u6YcT4kV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BSCpoY7H, 0, m, &cVar_BSCpoY7H_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CrvLiuVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_unf865fb, HV_BINOP_MULTIPLY, 0, m, &cBinop_unf865fb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LYsLnDgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gvs09Kuq, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gvs09Kuq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xM4dDsXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POQm0h9u, HV_BINOP_MULTIPLY, 0, m, &cBinop_POQm0h9u_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9dgFK2Uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_TqVFkzcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FV8BP622, HV_BINOP_MULTIPLY, 0, m, &cBinop_FV8BP622_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SScxZBiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_49oxELmw, HV_BINOP_MULTIPLY, 0, m, &cBinop_49oxELmw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iZjaWRHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6JwOcHEb, 0, m, &cVar_6JwOcHEb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GommmiGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_elYxWOC3, 0, m, &cVar_elYxWOC3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d6bBW83M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hegu2akz, 1, m, &cIf_hegu2akz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PuS0khCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Gbs2tjbJ, m);
}

void Heavy_WSTD_EQ::cBinop_VzQPVnO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PuS0khCr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4LSjC46c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hegu2akz, 0, m, &cIf_hegu2akz_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_4388wl4U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HQMnGgpf, 0, m, &cSlice_HQMnGgpf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DnyvdBM8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_HQMnGgpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Sc2JKZlF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Sc2JKZlF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Br4Jg7yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Sc2JKZlF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Sc2JKZlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4XcUMFD4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_T7X9QhEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aqM3zEKb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jeN22Ah6, 0, m, &cIf_jeN22Ah6_sendMessage);
}

void Heavy_WSTD_EQ::cIf_jeN22Ah6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2EyxcWsK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_rNlLTCoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZVlWkuvl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_p6pMyQPV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_VczFl9ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtUckfxQ, HV_BINOP_POW, 0, m, &cBinop_GtUckfxQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GtUckfxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TWbAucI7, 0, m, &cIf_TWbAucI7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yRngRHnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6AF18NmQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YMUFt45d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rNlLTCoX, 0, m, &cIf_rNlLTCoX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eTFo5wdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fvRfRsnz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fvRfRsnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rNlLTCoX, 1, m, &cIf_rNlLTCoX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p6pMyQPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yRngRHnJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZVlWkuvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TWbAucI7, 0, m, &cIf_TWbAucI7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6AF18NmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtUckfxQ, HV_BINOP_POW, 1, m, &cBinop_GtUckfxQ_sendMessage);
  cMsg_VczFl9ps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_TWbAucI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uYjoKaUb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_aqM3zEKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jeN22Ah6, 1, m, &cIf_jeN22Ah6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2EyxcWsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7v0g691, HV_BINOP_GREATER_THAN, 1, m, &cBinop_t7v0g691_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSoFGGPW, HV_BINOP_EQ, 1, m, &cBinop_gSoFGGPW_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_gKypZKNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ypxwnv5V, HV_BINOP_ADD, 0, m, &cBinop_Ypxwnv5V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ypxwnv5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eTFo5wdc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YMUFt45d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_t7v0g691_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TWbAucI7, 1, m, &cIf_TWbAucI7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gSoFGGPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R5B4o4pl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_R5B4o4pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uYjoKaUb, m);
}

void Heavy_WSTD_EQ::cCast_29wjeWnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ypxwnv5V, HV_BINOP_ADD, 1, m, &cBinop_Ypxwnv5V_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7v0g691, HV_BINOP_GREATER_THAN, 0, m, &cBinop_t7v0g691_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gSoFGGPW, HV_BINOP_EQ, 0, m, &cBinop_gSoFGGPW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ejUg8sSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T7X9QhEh, 0, m, &cVar_T7X9QhEh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EHqiik9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gKypZKNz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_rNY7SybR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hsnO3u9E_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_o3AK0O9J, 0, m, &cIf_o3AK0O9J_sendMessage);
}

void Heavy_WSTD_EQ::cIf_o3AK0O9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mBkd4v0e_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_wd1NqYVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uhZDejhg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4sZZL9to_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_TP440H09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_az2yH9Qp, HV_BINOP_POW, 0, m, &cBinop_az2yH9Qp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_az2yH9Qp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SdJx2VsY, 0, m, &cIf_SdJx2VsY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mlSUFpXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_piatTCP5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LgJCmxmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GzKqfsVm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EVe8PKFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wd1NqYVt, 0, m, &cIf_wd1NqYVt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GzKqfsVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wd1NqYVt, 1, m, &cIf_wd1NqYVt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4sZZL9to_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mlSUFpXt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uhZDejhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SdJx2VsY, 0, m, &cIf_SdJx2VsY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_piatTCP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_az2yH9Qp, HV_BINOP_POW, 1, m, &cBinop_az2yH9Qp_sendMessage);
  cMsg_TP440H09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_SdJx2VsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nsBv7zB2_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nM0z4X9v_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_ahUSDYKg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_hsnO3u9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o3AK0O9J, 1, m, &cIf_o3AK0O9J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mBkd4v0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uAeNsrD2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_uAeNsrD2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OHYW1hNr, HV_BINOP_EQ, 1, m, &cBinop_OHYW1hNr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3BJSdPB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ddvQpFm, HV_BINOP_ADD, 0, m, &cBinop_3ddvQpFm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3ddvQpFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LgJCmxmp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EVe8PKFT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uAeNsrD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SdJx2VsY, 1, m, &cIf_SdJx2VsY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OHYW1hNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vG7FcyqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_vG7FcyqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nsBv7zB2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nM0z4X9v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_ahUSDYKg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kE87zTNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3BJSdPB3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_lg4AtkSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ddvQpFm, HV_BINOP_ADD, 1, m, &cBinop_3ddvQpFm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uAeNsrD2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_uAeNsrD2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OHYW1hNr, HV_BINOP_EQ, 0, m, &cBinop_OHYW1hNr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MV9GTDXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rNY7SybR, 0, m, &cVar_rNY7SybR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_M3so6w36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YdnVsZuZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Pc8u0hIX, 0, m, &cIf_Pc8u0hIX_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Pc8u0hIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7v7EYEq5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_R580Dnqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_nXjYN1jr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_As364Y5E_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_Hpb35bdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxO7qwl0, HV_BINOP_POW, 0, m, &cBinop_qxO7qwl0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qxO7qwl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ez1mpYHk, 0, m, &cIf_ez1mpYHk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2t8s8jxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ORXaktoW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Uoo01CtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rUwS4NTH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lnOLGc9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R580Dnqo, 0, m, &cIf_R580Dnqo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rUwS4NTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R580Dnqo, 1, m, &cIf_R580Dnqo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_As364Y5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2t8s8jxG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_nXjYN1jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ez1mpYHk, 0, m, &cIf_ez1mpYHk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ORXaktoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxO7qwl0, HV_BINOP_POW, 1, m, &cBinop_qxO7qwl0_sendMessage);
  cMsg_Hpb35bdX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_ez1mpYHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qM4P4pBb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_YdnVsZuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Pc8u0hIX, 1, m, &cIf_Pc8u0hIX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7v7EYEq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wAbnv0NA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wAbnv0NA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_40Jb2wMV, HV_BINOP_EQ, 1, m, &cBinop_40Jb2wMV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2swuJS9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sBy6LxZj, HV_BINOP_ADD, 0, m, &cBinop_sBy6LxZj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sBy6LxZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uoo01CtS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lnOLGc9b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wAbnv0NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ez1mpYHk, 1, m, &cIf_ez1mpYHk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_40Jb2wMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9I3lC6jr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_9I3lC6jr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qM4P4pBb, m);
}

void Heavy_WSTD_EQ::cCast_mKIWyt4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2swuJS9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_W3Fov3P3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M3so6w36, 0, m, &cVar_M3so6w36_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V7E47729_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sBy6LxZj, HV_BINOP_ADD, 1, m, &cBinop_sBy6LxZj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wAbnv0NA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wAbnv0NA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_40Jb2wMV, HV_BINOP_EQ, 0, m, &cBinop_40Jb2wMV_sendMessage);
}

void Heavy_WSTD_EQ::cIf_oAvwWFyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_imdt7unY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_NWUUBKNA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yYEKLX4B, 0, m, &cSlice_yYEKLX4B_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FYVy4NBw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_yYEKLX4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LcEVLJuP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LcEVLJuP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_uzeBdUDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LcEVLJuP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_LcEVLJuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AJbg2aFT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_FYVy4NBw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zzlKqhZg, 0, m, &cSlice_zzlKqhZg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4388wl4U_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_zzlKqhZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_B7U9ZK3t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_B7U9ZK3t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_o1UnoAVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B7U9ZK3t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_B7U9ZK3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A1oOmAvz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_DnyvdBM8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BUSsijos, 0, m, &cSlice_BUSsijos_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MMqyJwGq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_BUSsijos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hD1ItkDy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hD1ItkDy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_AscovyCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hD1ItkDy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hD1ItkDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QREqYDAw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_MMqyJwGq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hE4ipsRe, 0, m, &cSlice_hE4ipsRe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_hE4ipsRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bmB3nopI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bmB3nopI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_uulvHMyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bmB3nopI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bmB3nopI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yssEoLKe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_agcvldU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bDn5AKXO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eRNa6KbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VgNX9ncw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ful8laZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H3eeqbEc, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uz8ZHtwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UuncZiBo, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_PEbLZdPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ctnrfAT1, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_MMq7J8EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BUyd8rHd_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_BUyd8rHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qXLsG593, HV_BINOP_DIVIDE, 1, m, &cBinop_qXLsG593_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sYZLxT32_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_tw8YCMz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_gS008QvU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_12ZVrAwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_tw8YCMz9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gS008QvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qXLsG593, HV_BINOP_DIVIDE, 0, m, &cBinop_qXLsG593_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sYZLxT32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_12ZVrAwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qXLsG593_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pKpdxd4K, HV_BINOP_MULTIPLY, 1, m, &cBinop_pKpdxd4K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pKpdxd4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r3xht74j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KoMjQoyD_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_NBQD3GxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Dk3ZM8wh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_JOXLahM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UIfJbyvo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_fzawCbDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_lZK6F3W7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lZK6F3W7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pKpdxd4K, HV_BINOP_MULTIPLY, 0, m, &cBinop_pKpdxd4K_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uqu45Wb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_YNtHPbAa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YNtHPbAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pao8RF2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_0lIpxNXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tm6Kshoh, 1, m, &cVar_Tm6Kshoh_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Tm6Kshoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0EabteDx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1jn3QTOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IjH85kEb, HV_BINOP_MULTIPLY, 1, m, &cBinop_IjH85kEb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XDs28JwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1jn3QTOG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_juxC5iJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JdU9Wt54_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JdU9Wt54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uoRsfrTY, HV_BINOP_MULTIPLY, 1, m, &cBinop_uoRsfrTY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SjHLRRn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yBmjV1sP, HV_BINOP_MULTIPLY, 1, m, &cBinop_yBmjV1sP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eqEQ1gjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SjHLRRn2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BtmS0Zrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFZtjTWt, HV_BINOP_MULTIPLY, 1, m, &cBinop_lFZtjTWt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_trqte7M8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RFKifFLE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RFKifFLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_74AJzyVY, HV_BINOP_MULTIPLY, 1, m, &cBinop_74AJzyVY_sendMessage);
}

void Heavy_WSTD_EQ::cVar_koEBCmiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M6F6BXJK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_fzawCbDS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VTtdCvJC_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Zspa6EZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_uqu45Wb3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r3xht74j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NBQD3GxF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KoMjQoyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JOXLahM0_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Dk3ZM8wh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TUPXcmRb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UIfJbyvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ND4gzReP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_OsGG86cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oV4aTWjE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_pao8RF2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_amL7Ud1F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_amL7Ud1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0mCy4vR, HV_BINOP_MULTIPLY, 1, m, &cBinop_p0mCy4vR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p0mCy4vR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Fy499Tnx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fy499Tnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OsGG86cp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_0EabteDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UMMDphwg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UMMDphwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2iF4ELAY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lfvXlcSo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KyHQdTWM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozqZ2t2D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_plAMAJYT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fp50sulh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IjH85kEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_agcvldU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uoRsfrTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eRNa6KbM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yBmjV1sP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ful8laZ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lFZtjTWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uz8ZHtwW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_74AJzyVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PEbLZdPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_PkKs3WUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_koEBCmiB, 0, m, &cVar_koEBCmiB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_St8AfbJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zspa6EZe, 1, m, &cVar_Zspa6EZe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ozqZ2t2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yBmjV1sP, HV_BINOP_MULTIPLY, 0, m, &cBinop_yBmjV1sP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2iF4ELAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_fp50sulh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IjH85kEb, HV_BINOP_MULTIPLY, 0, m, &cBinop_IjH85kEb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KyHQdTWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFZtjTWt, HV_BINOP_MULTIPLY, 0, m, &cBinop_lFZtjTWt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_plAMAJYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uoRsfrTY, HV_BINOP_MULTIPLY, 0, m, &cBinop_uoRsfrTY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lfvXlcSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_74AJzyVY, HV_BINOP_MULTIPLY, 0, m, &cBinop_74AJzyVY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_M6F6BXJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zspa6EZe, 0, m, &cVar_Zspa6EZe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VTtdCvJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tm6Kshoh, 0, m, &cVar_Tm6Kshoh_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FutksYDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lCQraw1l, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IDRGfm1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EosRuq2Z, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_8Vq58HLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q6mA0Sy7, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_cT9wiS3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pLGVrIIS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BtcHjImf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uCRHI0lx_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_uCRHI0lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Dcrrlnd, HV_BINOP_DIVIDE, 1, m, &cBinop_5Dcrrlnd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GfCCC0cb_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_rdNXTh9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pCIy5uO8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Z9R4mXyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rdNXTh9M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pCIy5uO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Dcrrlnd, HV_BINOP_DIVIDE, 0, m, &cBinop_5Dcrrlnd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GfCCC0cb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z9R4mXyP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5Dcrrlnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gjkvc0oJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gjkvc0oJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Gjkvc0oJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sgowlunl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ribGxCPg_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_YEWTyzN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5EE6jnP1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_3vrdHDjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JA24TVDT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_W8mGZLm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MluBFVOc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MluBFVOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gjkvc0oJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gjkvc0oJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WtPCcl5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qoaOABPT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qoaOABPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x6AqtCIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gLULnQjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G6NSCXvZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_G6NSCXvZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bOqp5u4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_glX11rbY, 1, m, &cVar_glX11rbY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PCgrtIHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kCs68pGE, HV_BINOP_MULTIPLY, 1, m, &cBinop_kCs68pGE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PfmJnP1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KZsxynh6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KZsxynh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xa1csqtj, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xa1csqtj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_glX11rbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DZQFWOxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_s3Yvbn4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nnRvf8OF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_W8mGZLm7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7p4DwPaX_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5EJCl2jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_WtPCcl5X_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Sgowlunl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_YEWTyzN9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ribGxCPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3vrdHDjL_sendMessage);
}

void Heavy_WSTD_EQ::cSend_5EE6jnP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DpWMp1sP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JA24TVDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_suYNHIOA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_XUuGBuQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yJedujsH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_x6AqtCIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Hg9QDBqO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hg9QDBqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5bQdCiCe, HV_BINOP_MULTIPLY, 1, m, &cBinop_5bQdCiCe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5bQdCiCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rRnbXRgt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rRnbXRgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XUuGBuQ7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_DZQFWOxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OMSsThZ6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OMSsThZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xlNbgKrE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GYuwVoLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hi57PauG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_osi7gBjj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tykwSlaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FutksYDD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_G6NSCXvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IDRGfm1f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kCs68pGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Vq58HLc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Xa1csqtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cT9wiS3w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_oZetIbWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5EJCl2jk, 1, m, &cVar_5EJCl2jk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kxQgXQOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s3Yvbn4B, 0, m, &cVar_s3Yvbn4B_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7p4DwPaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_glX11rbY, 0, m, &cVar_glX11rbY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nnRvf8OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5EJCl2jk, 0, m, &cVar_5EJCl2jk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Hi57PauG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G6NSCXvZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_G6NSCXvZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GYuwVoLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kCs68pGE, HV_BINOP_MULTIPLY, 0, m, &cBinop_kCs68pGE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_osi7gBjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tykwSlaw, HV_BINOP_MULTIPLY, 0, m, &cBinop_tykwSlaw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xlNbgKrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xa1csqtj, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xa1csqtj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bPlgMsSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uGwzNEMM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ToTJuXP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8tA9TQge, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BsBl3jAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3kKKUQPB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_k4PhwRSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qCPThttB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_i3QyYWMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mD1VSZbX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_O6ORVgZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7g7bk96W_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_7g7bk96W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AEqorDIr, HV_BINOP_DIVIDE, 1, m, &cBinop_AEqorDIr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jnKVly4J_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_jufwSZHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_RDzEAtO7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MqnLGjc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jufwSZHQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RDzEAtO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AEqorDIr, HV_BINOP_DIVIDE, 0, m, &cBinop_AEqorDIr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jnKVly4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MqnLGjc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AEqorDIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mbYVjCwg, HV_BINOP_MULTIPLY, 1, m, &cBinop_mbYVjCwg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mbYVjCwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LqawKBWQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XvfPNpp0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_sEJ5T9ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2wIInUIy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_3yyhY2ML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uonLI4yp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4PO6Nz90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_TibQ24tU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TibQ24tU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mbYVjCwg, HV_BINOP_MULTIPLY, 0, m, &cBinop_mbYVjCwg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bUYqTYE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ngPUtPIt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ngPUtPIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L1uoW6Mk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SZbhEqsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQbsdThi, HV_BINOP_MULTIPLY, 1, m, &cBinop_GQbsdThi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_43wzWFlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7WETABvg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7WETABvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SZbhEqsg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vFdyNRgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jqMkANrc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jqMkANrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tF0Qiofn, HV_BINOP_MULTIPLY, 1, m, &cBinop_tF0Qiofn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TPmUmvta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AMidWWVp, HV_BINOP_MULTIPLY, 1, m, &cBinop_AMidWWVp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Te1aaPAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_B5cIh5pE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_B5cIh5pE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TPmUmvta_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mD9IzXJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IKs62bYO, 1, m, &cVar_IKs62bYO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HT7bOXkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PH1sFFme, HV_BINOP_MULTIPLY, 1, m, &cBinop_PH1sFFme_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Cb321uzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KKRWzRDP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KKRWzRDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mGGxboUc, HV_BINOP_MULTIPLY, 1, m, &cBinop_mGGxboUc_sendMessage);
}

void Heavy_WSTD_EQ::cVar_IKs62bYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rKM67wxM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_vkAJgrxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z5gShRKP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_4PO6Nz90_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aWzH2jdw_sendMessage);
}

void Heavy_WSTD_EQ::cVar_f2AfhINi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_bUYqTYE6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XvfPNpp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3yyhY2ML_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LqawKBWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_sEJ5T9ZR_sendMessage);
}

void Heavy_WSTD_EQ::cSend_2wIInUIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fAu0SWTk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_uonLI4yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bavDyRbY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_S51QmdCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0GkxWIxQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_L1uoW6Mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3vx54RUj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3vx54RUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PsmVtNMP, HV_BINOP_MULTIPLY, 1, m, &cBinop_PsmVtNMP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PsmVtNMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LVpLFhez_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LVpLFhez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S51QmdCx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_rKM67wxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZsszaDye_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZsszaDye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qHn4tQgW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T93FZARq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iD3bQpkD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vh0d01Dt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WuCvXVdz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Skj6QyRg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GQbsdThi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bPlgMsSt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tF0Qiofn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ToTJuXP6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AMidWWVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BsBl3jAJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PH1sFFme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k4PhwRSi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mGGxboUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i3QyYWMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Z2jMiTxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f2AfhINi, 1, m, &cVar_f2AfhINi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_T5NrIhzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vkAJgrxW, 0, m, &cVar_vkAJgrxW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WuCvXVdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tF0Qiofn, HV_BINOP_MULTIPLY, 0, m, &cBinop_tF0Qiofn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_T93FZARq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mGGxboUc, HV_BINOP_MULTIPLY, 0, m, &cBinop_mGGxboUc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Vh0d01Dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AMidWWVp, HV_BINOP_MULTIPLY, 0, m, &cBinop_AMidWWVp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qHn4tQgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_Skj6QyRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQbsdThi, HV_BINOP_MULTIPLY, 0, m, &cBinop_GQbsdThi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iD3bQpkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PH1sFFme, HV_BINOP_MULTIPLY, 0, m, &cBinop_PH1sFFme_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Z5gShRKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f2AfhINi, 0, m, &cVar_f2AfhINi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aWzH2jdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IKs62bYO, 0, m, &cVar_IKs62bYO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nsBv7zB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oAvwWFyA, 1, m, &cIf_oAvwWFyA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DjQmPxTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_imdt7unY, m);
}

void Heavy_WSTD_EQ::cBinop_nM0z4X9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DjQmPxTY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ahUSDYKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oAvwWFyA, 0, m, &cIf_oAvwWFyA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_srUt5FMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9xm3CFtV, HV_BINOP_DIVIDE, 0, m, &cBinop_9xm3CFtV_sendMessage);
}

void Heavy_WSTD_EQ::cVar_HY9vsU4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkR4dcFO, HV_BINOP_DIVIDE, 1, m, &cBinop_XkR4dcFO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9xm3CFtV, HV_BINOP_DIVIDE, 1, m, &cBinop_9xm3CFtV_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_2ZmsZwha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KxEUMr0z, HV_BINOP_DIVIDE, 0, m, &cBinop_KxEUMr0z_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_4UWOMCxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KxEUMr0z, HV_BINOP_DIVIDE, 1, m, &cBinop_KxEUMr0z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hpd8VV9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XkR4dcFO, HV_BINOP_DIVIDE, 0, m, &cBinop_XkR4dcFO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wfEbL3pB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_srUt5FMH, 0, m, &cVar_srUt5FMH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HF5JO4Up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HY9vsU4N, 0, m, &cVar_HY9vsU4N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XkR4dcFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_2ZmsZwha_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9xm3CFtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_4UWOMCxE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KxEUMr0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_WbqrcWjV_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_sbmF9GuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_1qh6nu8f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nYJ2yYOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_pECUAwDu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WbqrcWjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nYJ2yYOd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pECUAwDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_sbmF9GuF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1qh6nu8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_48fykbLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_jpaMLmKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MmrXYs3Z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NWUUBKNA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_oWxfXW61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MmrXYs3Z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NWUUBKNA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7ayb8nIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MmrXYs3Z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NWUUBKNA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bnpQBsKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MmrXYs3Z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NWUUBKNA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_48fykbLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MmrXYs3Z_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NWUUBKNA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rxIMVW14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_W6tFkCGx, 0, m, &cVar_W6tFkCGx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7nQzBKGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_sbpPCCGw, 0, m, &cVar_sbpPCCGw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cWo9gxkv, 0, m, &cVar_cWo9gxkv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nUVabuMa, 0, m, &cVar_nUVabuMa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_HOhUh8Nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sbpPCCGw, 0, m, &cVar_sbpPCCGw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_fGW3ErXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cWo9gxkv, 0, m, &cVar_cWo9gxkv_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tCz1uxnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nUVabuMa, 0, m, &cVar_nUVabuMa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sREI5qbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w9urElia, 0, m, &cVar_w9urElia_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_zumbgOOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EMC3MmJQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BGxe1VUJ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_jBh0Kzh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A4vU5g0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oda20OHZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Mi4uZ3v_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YGQ6qBDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2TbpiJuU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2qXmL8SH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qAlZcnzu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_SOZQuDks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4AK04kFC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pF5kpmu0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zue9kSr2_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_2jDlqv2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NXFD6YmF_sendMessage(_c, 0, m);
  cMsg_qRk6ITuw_sendMessage(_c, 0, m);
  cMsg_GGOsaSDc_sendMessage(_c, 0, m);
  cMsg_MMq7J8EO_sendMessage(_c, 0, m);
  cMsg_BtcHjImf_sendMessage(_c, 0, m);
  cMsg_O6ORVgZh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_l5DWwum2, 0, m, &cVar_l5DWwum2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w9urElia, 0, m, &cVar_w9urElia_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BSCpoY7H, 0, m, &cVar_BSCpoY7H_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_koEBCmiB, 0, m, &cVar_koEBCmiB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s3Yvbn4B, 0, m, &cVar_s3Yvbn4B_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vkAJgrxW, 0, m, &cVar_vkAJgrxW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nnAOChJq, 0, m, &cVar_nnAOChJq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gQYefG2P, 0, m, &cVar_gQYefG2P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m45ByE2z, 0, m, &cVar_m45ByE2z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_z2jW8X3p, 0, m, &cVar_z2jW8X3p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E8T7HRpH, 0, m, &cVar_E8T7HRpH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3hfgpU3t, 0, m, &cVar_3hfgpU3t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vQSOoHap, 0, m, &cVar_vQSOoHap_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hr2x1d1W, 0, m, &cVar_hr2x1d1W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Br4Jg7yu, 0, m, &cVar_Br4Jg7yu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T7X9QhEh, 0, m, &cVar_T7X9QhEh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rNY7SybR, 0, m, &cVar_rNY7SybR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_M3so6w36, 0, m, &cVar_M3so6w36_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uzeBdUDX, 0, m, &cVar_uzeBdUDX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o1UnoAVD, 0, m, &cVar_o1UnoAVD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AscovyCN, 0, m, &cVar_AscovyCN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uulvHMyW, 0, m, &cVar_uulvHMyW_sendMessage);
  cMsg_7nQzBKGY_sendMessage(_c, 0, m);
  cMsg_rxIMVW14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_dyDORE99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oc7l89XA, HV_BINOP_MULTIPLY, 0, m, &cBinop_Oc7l89XA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IzEaegL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_L6eOtBot_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Z1BfVlfm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zkLSjlLF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cnrEq9hz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_M1WPiQwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xq7mXJUl_sendMessage);
  cMsg_V7QN492f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_61nkVSmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H7lHpK35, HV_BINOP_MULTIPLY, 0, m, &cBinop_H7lHpK35_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_jTXJOqSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7zZaOCR6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FXtZKsMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M4SFKHtH, HV_BINOP_MULTIPLY, 1, m, &cBinop_M4SFKHtH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BSkDaKzf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VUTBUkgu_sendMessage);
  cMsg_zhJYhF8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_byf4zQlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ASN6Vwnt, HV_BINOP_MULTIPLY, 0, m, &cBinop_ASN6Vwnt_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_fD3Ckcvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fsY5CSSH_sendMessage(_c, 0, m);
  cMsg_9cYcq3JV_sendMessage(_c, 0, m);
  cMsg_DmoxZ5WB_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_DgtPMMbr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_mkOurOaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AFMzrp8H_sendMessage);
  cMsg_OJ7X0xIo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_4XcUMFD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s3Yvbn4B, 0, m, &cVar_s3Yvbn4B_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_yssEoLKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oZetIbWX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kxQgXQOg_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_AJbg2aFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ejUg8sSg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_29wjeWnH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EHqiik9Y_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_QREqYDAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W3Fov3P3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V7E47729_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mKIWyt4M_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_A1oOmAvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MV9GTDXe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lg4AtkSf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kE87zTNa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_TUPXcmRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0mCy4vR, HV_BINOP_MULTIPLY, 0, m, &cBinop_p0mCy4vR_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ND4gzReP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XDs28JwT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_juxC5iJh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eqEQ1gjN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BtmS0Zrs_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_oV4aTWjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0lIpxNXB_sendMessage);
  cMsg_trqte7M8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_DpWMp1sP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5bQdCiCe, HV_BINOP_MULTIPLY, 0, m, &cBinop_5bQdCiCe_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_suYNHIOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_PCgrtIHK_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_yJedujsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tykwSlaw, HV_BINOP_MULTIPLY, 1, m, &cBinop_tykwSlaw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gLULnQjk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bOqp5u4N_sendMessage);
  cMsg_PfmJnP1E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_fAu0SWTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PsmVtNMP, HV_BINOP_MULTIPLY, 0, m, &cBinop_PsmVtNMP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bavDyRbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_43wzWFlf_sendMessage(_c, 0, m);
  cMsg_vFdyNRgk_sendMessage(_c, 0, m);
  cMsg_Te1aaPAT_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HT7bOXkz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0GkxWIxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mD9IzXJO_sendMessage);
  cMsg_Cb321uzU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_OuwszPb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W6tFkCGx, 0, m, &cVar_W6tFkCGx_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_hmSBeQ4E, VOf(Bf0));
    __hv_varread_f(&sVarf_zkzUm6K2, VOf(Bf1));
    __hv_varread_f(&sVarf_cQy3V7im, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_jtC7raYm, VOf(Bf0));
    __hv_varread_f(&sVarf_jMnYOXsR, VOf(Bf1));
    __hv_varread_f(&sVarf_bhFdefn5, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_xwQq68k5, VOf(Bf0));
    __hv_line_f(&sLine_R4ZCCfpf, VOf(Bf1));
    __hv_line_f(&sLine_nftXhldO, VOf(Bf4));
    __hv_line_f(&sLine_QTVS3zlb, VOf(Bf5));
    __hv_line_f(&sLine_wVzFe3A5, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_fB8t46dP, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Xi2yLdY1, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_y0b5ULk4, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_spllSADz, VOf(Bf1));
    __hv_line_f(&sLine_IQZuMiV2, VOf(Bf0));
    __hv_line_f(&sLine_xzJVUKeL, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_YHBxLEJE, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_Gbs2tjbJ, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_uiFswhpa, VOf(Bf7));
    __hv_line_f(&sLine_8PaH7ACC, VOf(Bf1));
    __hv_line_f(&sLine_Tf9LN3Fe, VOf(Bf4));
    __hv_line_f(&sLine_XPZfroET, VOf(Bf6));
    __hv_line_f(&sLine_vo9Jjnz9, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_73KMs3pp, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_V2cMVnti, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_hmSBeQ4E, VIf(Bf5));
    __hv_varwrite_f(&sVarf_zkzUm6K2, VIf(Bf0));
    __hv_varwrite_f(&sVarf_cQy3V7im, VIf(Bf6));
    __hv_line_f(&sLine_bDn5AKXO, VOf(Bf6));
    __hv_line_f(&sLine_VgNX9ncw, VOf(Bf0));
    __hv_line_f(&sLine_H3eeqbEc, VOf(Bf5));
    __hv_line_f(&sLine_UuncZiBo, VOf(Bf8));
    __hv_line_f(&sLine_ctnrfAT1, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_dU8GZIpL, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_uYjoKaUb, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_lCQraw1l, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_EosRuq2Z, VOf(Bf0));
    __hv_line_f(&sLine_Q6mA0Sy7, VOf(Bf6));
    __hv_line_f(&sLine_pLGVrIIS, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_0QLT9Pv8, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_imdt7unY, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_uGwzNEMM, VOf(Bf1));
    __hv_line_f(&sLine_8tA9TQge, VOf(Bf0));
    __hv_line_f(&sLine_3kKKUQPB, VOf(Bf5));
    __hv_line_f(&sLine_qCPThttB, VOf(Bf4));
    __hv_line_f(&sLine_mD1VSZbX, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_FIhojla5, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_qM4P4pBb, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_jtC7raYm, VIf(Bf8));
    __hv_varwrite_f(&sVarf_jMnYOXsR, VIf(Bf6));
    __hv_varwrite_f(&sVarf_bhFdefn5, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
